@@ -26,6 +26,8 @@ from winrm.exceptions import (InvalidCredentialsError,
                               WinRMTransportError,
                               WinRMOperationTimeoutError)
 
+from pywinos.exceptions import ServiceLookupError
+
 
 class ResponseParser:
     """Response parser"""
@@ -114,16 +116,13 @@ class WinOSClient:
         self.host = host
         self.username = username
         self.password = password
-        self.logger_enabled = logger_enabled
-        self.logger = plogger.logger(self.__class__.__name__)
-        self.logger.disabled = not self.logger_enabled
+        self.logger = plogger.logger(self.__class__.__name__, enabled=logger_enabled)
 
     def __str__(self):
         return (f'Local host: {self.get_current_os_name_local()}\n'
                 f'Remote IP: {self.host}\n'
                 f'Username: {self.username}\n'
-                f'Password: {self.password}\n'
-                f'Logger enabled: {self.logger_enabled}')
+                f'Password: {self.password}\n')
 
     def list_all_methods(self):
         """Returns all available public methods"""
@@ -473,7 +472,7 @@ class WinOSClient:
 
         result = self.run_ps(cmd).stdout
         if result is None:
-            self.logger.info('Nothing found. Dont\'t forget to use wildcards.')
+            self.logger.info('Nothing found. Do not forget to use wildcards.')
             return []
 
         result_list = result.splitlines()
@@ -509,7 +508,7 @@ class WinOSClient:
         return entities_list
 
     def get_file_version(self, path: str, version: str = 'Product') -> str:
-        """Get remote windows file version from file property
+        """Get remote Windows file version from file property
 
         :param path: Full path to the file
         :param version: ProductVersion | File
@@ -520,7 +519,7 @@ class WinOSClient:
         return self.run_ps(cmd).stdout
 
     def get_file_version_local(self, path: str, version: str = 'Product') -> str:
-        """Get local windows file version from file property
+        """Get local Windows file version from file property
 
         :param path: Full path to the file
         :param version: ProductVersion | File
@@ -534,7 +533,7 @@ class WinOSClient:
         self.logger.error(f'File {path} not found.')
 
     def get_file_size(self, path: str) -> int:
-        """Get remote windows file size. Returns size in bytes.
+        """Get remote Windows file size. Returns size in bytes.
 
         :param path: Full path to the file
         :return:
@@ -547,7 +546,7 @@ class WinOSClient:
         return int(result.stdout)
 
     def get_file_size_local(self, path: str) -> int:
-        """Get local windows file size. Returns size in bytes.
+        """Get local Windows file size. Returns size in bytes.
 
         :param path: Full path to the file
         :return:
@@ -617,11 +616,14 @@ class WinOSClient:
 
     def get_xml(self):
         # (Select-Xml -Path D:\Test.xml -XPath "/configuration/parameters/logging/LogLevel").Node.Value
+
+        deprecate_msg = '.get_xml* methods deprecated and will be removed. Use xmltodict package and UNC path instead!'
+        self.logger.warning(deprecate_msg)
+
         msg = 'Use .run_ps() and "Select-Xml" cmdlet. Select-Xml -Path D:\\Test.xml -XPath "/configuration"'
         raise NotImplementedError(msg)
 
-    @staticmethod
-    def get_xml_dom_local(path: str, tag: str = None) -> Element:
+    def get_xml_dom_local(self, path: str, tag: str = None) -> Element:
         """Parse local XML file using dom.
 
         Methods to get info from dom: getElementsByTagName(), getElementById()
@@ -636,6 +638,9 @@ class WinOSClient:
         :return: root or tag element
         """
 
+        deprecation_message = '.get_xml*_local methods deprecated and will be removed. Use xmltodict package instead!'
+        self.logger.warning(deprecation_message)
+
         root = minidom.parse(path)
         if tag:
             return root.getElementsByTagName(tag)
@@ -649,6 +654,9 @@ class WinOSClient:
         :return: root or tag text
         """
 
+        deprecation_message = '.get_xml*_local methods deprecated and will be removed. Use xmltodict package instead!'
+        self.logger.warning(deprecation_message)
+
         import xml.etree.ElementTree as ET
 
         try:
@@ -758,7 +766,7 @@ class WinOSClient:
     def copy_local(self, source: str, destination: str, new_name: str = None) -> bool:
         """Copy local file to a local/remote server.
 
-        Creates destination directory if does not exist.
+        Creates destination directory if it does not exist.
 
         :param source: Source file to copy
         :param destination: Destination directory name. Not full file path.
@@ -845,33 +853,33 @@ class WinOSClient:
 
     # ---------- Service / process management ----------
     def get_service(self, name: str) -> json:
-        """Check windows service"""
+        """Check Windows service"""
 
         result = self.run_ps(f'Get-Service -Name {name} | ConvertTo-Json')
         try:
             return result.json()
         except TypeError:
             self.logger.error(f'Exit code: {result.exited}. {result.stderr}')
-            return {}
+            raise ServiceLookupError(name)
 
     def get_service_local(self, name: str) -> json:
-        """Check windows service"""
+        """Check Windows service"""
 
         result = self.run_ps_local(f'Get-Service -Name {name} | ConvertTo-Json')
         try:
             return result.json()
         except TypeError:
             self.logger.error(f'Exit code: {result.exited}. {result.stderr}')
-            return {}
+            raise ServiceLookupError(name)
 
     def get_service_status(self, name: str) -> str:
-        """Check windows service status"""
+        """Check Windows service status"""
 
         result = self.run_ps(f'(Get-Service -Name {name}).Status')
         return result.stdout
 
     def get_service_status_local(self, name: str) -> str:
-        """Check windows service status"""
+        """Check Windows service status"""
 
         result = self.run_ps_local(f'(Get-Service -Name {name}).Status')
         return result.stdout
@@ -909,7 +917,7 @@ class WinOSClient:
             return result.json()
         except TypeError:
             self.logger.error(f'Exit code: {result.exited}. {result.stderr}')
-            return {}
+            raise ProcessLookupError
 
     def get_process_local(self, name: str) -> json:
         """Check windows process status"""
@@ -920,7 +928,7 @@ class WinOSClient:
             return result.json()
         except TypeError:
             self.logger.error(f'Exit code: {result.exited}. {result.stderr}')
-            return {}
+            raise ProcessLookupError
 
     def kill_process(self, name: str) -> bool:
         """Kill windows local service status. Remote and local"""
@@ -1009,15 +1017,27 @@ class WinOSClient:
     def get_service_file_version(self, name: str) -> str:
         """Get FileVersion from the process"""
 
-        return self.run_ps(f'(Get-Process -Name {name}).FileVersion').stdout
+        result = self.run_ps(f'(Get-Process -Name {name}).FileVersion')
+
+        msg_err = f'Cannot find a process with the name "{name}"'
+        if msg_err in result.stderr:
+            self.logger.error(msg_err)
+            raise ProcessLookupError(msg_err)
+        return result.stdout
 
     def get_service_file_version_local(self, name: str) -> str:
         """Get FileVersion from the process"""
 
-        return self.run_ps_local(f'(Get-Process -Name {name}).FileVersion').stdout
+        result = self.run_ps_local(f'(Get-Process -Name {name}).FileVersion')
+
+        msg_err = f'Cannot find a process with the name "{name}"'
+        if msg_err in result.stderr:
+            self.logger.error(msg_err)
+            raise ProcessLookupError(msg_err)
+        return result.stdout
 
     def is_service_running(self, name: str) -> bool:
-        """Check local windows service is running"""
+        """Check local Windows service is running"""
 
         cmd = f'(Get-Service -Name {name}).Status -eq "running"'
         response = self.run_ps(cmd)
@@ -1026,7 +1046,7 @@ class WinOSClient:
         return False
 
     def is_service_running_local(self, name: str) -> bool:
-        """Check local windows service is running"""
+        """Check local Windows service is running"""
 
         cmd = f'(Get-Service -Name {name}).Status -eq "running"'
         response = self.run_ps_local(cmd)
@@ -1060,7 +1080,7 @@ class WinOSClient:
 
     # ------------------ Networking ----------------------
     def get_network_adapter_state(self, name: str) -> str:
-        """Get network adapter state in Windows by it's name
+        """Get network adapter state in Windows by its name
 
         :param name: DATA, SYNC
         :return:
@@ -1085,7 +1105,7 @@ class WinOSClient:
         return result.stdout
 
     def get_network_adapter_state_local(self, name: str) -> str:
-        """Get network adapter state in Windows by it's name
+        """Get network adapter state in Windows by its name
 
         :param name: DATA, SYNC
         :return:
@@ -1110,7 +1130,7 @@ class WinOSClient:
         return result.stdout
 
     def disable_network_adapter(self, name: str) -> bool:
-        """Disable network adapter in Windows by it's name
+        """Disable network adapter in Windows by its name
 
         Log info is adapter already disabled and return
 
@@ -1145,7 +1165,7 @@ class WinOSClient:
         return result.ok
 
     def disable_network_adapter_local(self, name: str) -> bool:
-        """Disable network adapter in Windows by it's name
+        """Disable network adapter in Windows by its name
 
         Log info is adapter already disabled and return
 
@@ -1180,7 +1200,7 @@ class WinOSClient:
         return result.ok
 
     def enable_network_adapter(self, name: str) -> bool:
-        """Enable network adapter in Windows by it's name
+        """Enable network adapter in Windows by its name
 
         Log info is adapter already disabled and return
 
@@ -1215,7 +1235,7 @@ class WinOSClient:
         return result.ok
 
     def enable_network_adapter_local(self, name: str) -> bool:
-        """Enable network adapter in Windows by it's name
+        """Enable network adapter in Windows by its name
 
         Log info is adapter already disabled and return
 
@@ -1254,7 +1274,7 @@ class WinOSClient:
 
         The value returned represents the most recently refreshed size of working set memory used by the process,
         in bytes or specific dimension.
-        To get the most up to date size, you need to call Refresh() method first.
+        To get the most up-to-date size, you need to call Refresh() method first.
 
         :param name: Service name
         :param dimension: KB | MB | GB
@@ -1280,7 +1300,7 @@ class WinOSClient:
 
         The value returned represents the most recently refreshed size of working set memory used by the process,
         in bytes or specific dimension.
-        To get the most up to date size, you need to call Refresh() method first.
+        To get the most up-to-date size, you need to call Refresh() method first.
 
         :param name: Service name
         :param dimension: KB | MB | GB
